@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 ###################################################
 #
-#  Copyright (C) 2008-2012 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2013 Mario Kemper <mario.kemper@gmail.com>
 #
 #  This file is part of Shutter.
 #
@@ -105,7 +105,7 @@ sub upload {
 			);
 
 			my @params = (
-				"http://imgur.com/api/upload.json",
+				"http://api.imgur.com/1/upload.json",
 				'Content_Type' => 'multipart/form-data',
 				'Content' => [%params]
 			);
